package com.example.f1hub.data.service

import com.example.f1hub.data.dto.out.ads.AdAllAttributesDto
import com.example.f1hub.data.dto.out.ads.AdNoIdDto
import com.example.f1hub.data.dto.`in`.ads.ResponseAd
import com.example.f1hub.data.network.InstanceRetrofit
import retrofit2.HttpException
import retrofit2.Response
import java.io.IOException
import javax.inject.Inject

class AdService @Inject constructor() {

    suspend fun getAllAds(token: String): List<ResponseAd> {
        return try {
            val response: Response<List<ResponseAd>> = InstanceRetrofit.retrofitService.getAllAds(token)
            if (response.isSuccessful) response.body() ?: emptyList() else emptyList()
        } catch (e: IOException) {
            emptyList()
        } catch (e: HttpException) {
            emptyList()
        }
    }

    suspend fun getAdById(token: String, id: Int): ResponseAd? {
        return try {
            val response: Response<ResponseAd> = InstanceRetrofit.retrofitService.getAdById(id, token)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }

    suspend fun deleteAd(token: String, id: Int): Boolean {
        return try {
            val response: Response<Unit> = InstanceRetrofit.retrofitService.deleteAd(id, token)
            response.isSuccessful
        } catch (e: IOException) {
            false
        } catch (e: HttpException) {
            false
        }
    }

    suspend fun editAd(token: String, editAd: AdAllAttributesDto): ResponseAd? {
        return try {
            val response: Response<ResponseAd> = InstanceRetrofit.retrofitService.updateAd(token, editAd)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }

    suspend fun addAd(token: String, addAd: AdNoIdDto): ResponseAd? {
        return try {
            val response: Response<ResponseAd> = InstanceRetrofit.retrofitService.addAd(token, addAd)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }
}
