package com.example.f1hub.data.service

import com.example.f1hub.data.dto.out.ads.AdAllAttributesDto
import com.example.f1hub.data.dto.out.ads.AdNoIdDto
import com.example.f1hub.data.dto.out.items.ItemsAllAttributesDto
import com.example.f1hub.data.dto.out.items.ItemsNoIdDto
import com.example.f1hub.data.dto.out.users.UserLoginDto
import com.example.f1hub.data.dto.`in`.ads.ResponseAd
import com.example.f1hub.data.dto.`in`.items.ResponseItem
import com.example.f1hub.data.dto.`in`.users.UserLoginResponse
import com.example.f1hub.data.dto.out.users.UserAllAttributesDto
import com.example.f1hub.data.dto.out.users.UserNoIdDto
import com.example.f1hub.data.dto.`in`.users.UserResponse
import retrofit2.Response
import retrofit2.http.*

interface ApiService {

    //USERS
    @POST("login")
    suspend fun login(@Body logUserLoginDto: UserLoginDto): Response<UserLoginResponse>
    @POST("register")
    suspend fun register(@Body registerUser: UserNoIdDto): Response<UserResponse>

    @POST("/validate-token")
    suspend fun validateToken(@Header("Authorization") token: String) : Response<Unit>

    @PUT("/users/edit")
    suspend fun updateUser(
        @Header("Authorization") token: String,
        @Body editUser: UserAllAttributesDto
    ): Response<UserResponse>

    @GET("users/{id}")
    suspend fun findUserById(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<UserResponse>

    //ADS
    @GET("ads")
    suspend fun getAllAds(@Header("Authorization") token: String): Response<List<ResponseAd>>
    @GET("ads/{id}")
    suspend fun getAdById(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<ResponseAd>

    @DELETE("ads/del/{id}")
    suspend fun deleteAd(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<Unit>

    @PUT("ads/edit")
    suspend fun updateAd(
        @Header("Authorization") token: String,
        @Body editItem: AdAllAttributesDto
    ): Response<ResponseAd>

    @POST("ads/add")
    suspend fun addAd(
        @Header("Authorization") token: String,
        @Body addAd: AdNoIdDto
    ): Response<ResponseAd>

    //ITEMS
    @GET("items")
    suspend fun getAllItems(@Header("Authorization") token: String): Response<List<ResponseItem>>

    @GET("items/user/{id}")
    suspend fun getAllItemsByUser(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<List<ResponseItem>>

    @GET("items/{id}")
    suspend fun getItemById(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<ResponseItem>

    @DELETE("items/del/{id}")
    suspend fun deleteItem(
        @Path("id") id: Int,
        @Header("Authorization") token: String
    ): Response<Unit>

    @PUT("items/edit")
    suspend fun updateItem(
        @Header("Authorization") token: String,
        @Body editItem: ItemsAllAttributesDto
    ): Response<ResponseItem>

    @POST("items/add")
    suspend fun addItem(
        @Header("Authorization") token: String,
        @Body addItem: ItemsNoIdDto
    ): Response<ResponseItem>
}
