package com.example.f1hub.data.service

import android.util.Log
import com.example.f1hub.data.dto.out.items.ItemsAllAttributesDto
import com.example.f1hub.data.dto.out.items.ItemsNoIdDto
import com.example.f1hub.data.dto.`in`.items.ResponseItem
import com.example.f1hub.data.network.InstanceRetrofit
import retrofit2.HttpException
import retrofit2.Response
import java.io.IOException
import javax.inject.Inject


class ItemService @Inject constructor() {
    suspend fun getAllItems(token: String): List<ResponseItem> {
        return try {
            val response: Response<List<ResponseItem>> = InstanceRetrofit.retrofitService.getAllItems(token)

            if (response.isSuccessful) response.body() ?: emptyList() else emptyList()
        } catch (e: IOException) {
            emptyList()
        } catch (e: HttpException) {
            emptyList()
        }
    }

    suspend fun getAllItemsByUser(id: Int,token: String): List<ResponseItem> {
        return try {
            val response: Response<List<ResponseItem>> = InstanceRetrofit.retrofitService.getAllItemsByUser(id,token)
            if (response.isSuccessful) response.body() ?: emptyList() else emptyList()
        } catch (e: IOException) {
            emptyList()
        } catch (e: HttpException) {
            emptyList()
        }
    }

    suspend fun getItemById(token: String, id: Int): ResponseItem? {
        return try {
            val response: Response<ResponseItem> = InstanceRetrofit.retrofitService.getItemById(id, token)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }

    suspend fun deleteItem(token: String, id: Int): Boolean {
        return try {
            val response: Response<Unit> = InstanceRetrofit.retrofitService.deleteItem(id, token)
            response.isSuccessful
        } catch (e: IOException) {
            false
        } catch (e: HttpException) {
            false
        }
    }

    suspend fun editItem(token: String, editItem: ItemsAllAttributesDto): ResponseItem? {
        return try {
            val response: Response<ResponseItem> = InstanceRetrofit.retrofitService.updateItem(token, editItem)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }

    suspend fun addItem(token: String, addItem: ItemsNoIdDto): ResponseItem? {
        return try {
            val response: Response<ResponseItem> = InstanceRetrofit.retrofitService.addItem(token,addItem)
            if (response.isSuccessful) response.body() else null
        } catch (e: IOException) {
            null
        } catch (e: HttpException) {
            null
        }
    }
}
