package com.example.f1hub.ui.adapter

import android.util.Log
import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.ImageView
import androidx.recyclerview.widget.RecyclerView
import com.example.f1hub.R
import com.example.f1hub.data.dto.`in`.ads.ResponseAd
import dagger.assisted.Assisted
import dagger.assisted.AssistedInject

class AdapterAnuncio @AssistedInject constructor(
    @Assisted private var list: MutableList<ResponseAd> = mutableListOf(),
    @Assisted private val onImageClick: (Int) -> Unit // Callback para manejar clics en la imagen
) : RecyclerView.Adapter<ViewHolderAnuncio>() {

    // Actualiza la lista de anuncios y notifica los cambios
    fun submitList(newList: MutableList<ResponseAd>) {
        list.clear()
        list.addAll(newList)
        notifyDataSetChanged()
    }

    // Crea y devuelve un ViewHolder inflando el layout correspondiente
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolderAnuncio {
        val layoutInflater = LayoutInflater.from(parent.context)
        return ViewHolderAnuncio(
            layoutInflater.inflate(R.layout.card_view_general, parent, false)
        )
    }

    // Devuelve la cantidad de elementos en la lista
    override fun getItemCount(): Int = list.size

    // Asigna los datos al ViewHolder y configura el clic en la imagen
    override fun onBindViewHolder(holder: ViewHolderAnuncio, position: Int) {
        val ad = list[position] // 🔹 Obtiene el ítem real desde la lista

        holder.itemView.findViewById<ImageView>(R.id.imagen).setOnClickListener {
            onImageClick(ad.id.toInt())
        }
        holder.renderize(ad)
    }

    // AssistedFactory para crear instancias de AdapterAnuncio
    @dagger.assisted.AssistedFactory
    interface Factory {
        fun create(
            list: MutableList<ResponseAd>,
            onImageClick: (Int) -> Unit
        ): AdapterAnuncio
    }
}
