package com.example.f1hub.ui.adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.ImageView
import androidx.recyclerview.widget.RecyclerView
import com.example.f1hub.R
import com.example.f1hub.data.dto.`in`.items.ResponseItem
import dagger.assisted.Assisted
import dagger.assisted.AssistedInject

// Adaptador para manejar una lista de Items en un RecyclerView
class AdapterItem @AssistedInject constructor(
    //Se asignan identificadores únicos a cada Assisted para evitar conflictos, puesto que existen varios
    @Assisted("list") private var list: MutableList<ResponseItem> = mutableListOf(),
    @Assisted("onDeleteClick") private val onDeleteClick: (Int) -> Unit, // Callback para eliminar un ítem
    @Assisted("onUpdateClick") private val onUpdateClick: (Int) -> Unit, // Callback para editar un ítem
    @Assisted("onImageClick") private val onImageClick: (Int) -> Unit   // Callback para hacer clic en la imagen
) : RecyclerView.Adapter<ViewHolderItem>() {

    // Crea y devuelve un ViewHolder inflando el layout correspondiente
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolderItem {
        val layoutInflater = LayoutInflater.from(parent.context)
        return ViewHolderItem(
            layoutInflater.inflate(R.layout.card_view_propio, parent, false)
        )
    }

    // Devuelve la cantidad de elementos en la lista
    override fun getItemCount(): Int = list.size

    // Asigna los datos al ViewHolder y configura los clics en los botones e imagen
    override fun onBindViewHolder(holder: ViewHolderItem, position: Int) {
        val item = list[position] // 🔹 Obtiene el ítem real desde la lista

        holder.itemView.findViewById<ImageView>(R.id.imagen).setOnClickListener {
            onImageClick(item.id.toInt())
        }
        holder.itemView.findViewById<ImageView>(R.id.edit).setOnClickListener {
            onUpdateClick(item.id.toInt())
        }
        holder.itemView.findViewById<ImageView>(R.id.delete).setOnClickListener {
            onDeleteClick(item.id.toInt())
        }

        holder.renderize(item)
    }


    // Método para actualizar la lista y notificar los cambios
    fun submitList(newList: List<ResponseItem>) {
        list.clear()
        list.addAll(newList)
        notifyDataSetChanged()
    }

    // AssistedFactory para crear instancias de AdapterItem
    @dagger.assisted.AssistedFactory
    interface Factory {
        fun create(
            @Assisted("list") list: MutableList<ResponseItem>,
            @Assisted("onDeleteClick") onDeleteClick: (Int) -> Unit,
            @Assisted("onUpdateClick") onUpdateClick: (Int) -> Unit,
            @Assisted("onImageClick") onImageClick: (Int) -> Unit
        ): AdapterItem
    }
}
