package com.example.f1hub.ui.view.fragment.content

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.lifecycle.Observer
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.f1hub.R
import com.example.f1hub.ui.adapter.AdapterAnuncio
import com.example.f1hub.databinding.FragmentItemsGeneralBinding
import com.example.f1hub.ui.view.MainActivity
import com.example.f1hub.ui.view.login.Login
import com.example.f1hub.ui.viewmodel.AnuncioViewModel
import dagger.hilt.android.AndroidEntryPoint

// Anota el fragment con @AndroidEntryPoint para que Hilt pueda inyectar las dependencias
@AndroidEntryPoint
class AnuncioFragment : Fragment() {

    private lateinit var binding: FragmentItemsGeneralBinding
    // Inyección del ViewModel (Hilt lo resolverá si está configurado en el proyecto)
    private val viewModel: AnuncioViewModel by viewModels()
    private lateinit var adapter: AdapterAnuncio

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentItemsGeneralBinding.inflate(inflater, container, false)

        // Inicializar Adapter
        adapter = AdapterAnuncio { id ->
            onAnuncioClick(id)
        }

        // Configurar RecyclerView
        binding.myRecyclerView.layoutManager = LinearLayoutManager(requireContext())
        binding.myRecyclerView.adapter = adapter

        // Observar los cambios en la lista de anuncios
        viewModel.anuncioLiveData.observe(viewLifecycleOwner, Observer { anuncios ->
            adapter.submitList(anuncios.toMutableList()) // Pasar lista actualizada al Adapter
        })

        // Observa el estado del ProgressBar y lo muestra/oculta
        viewModel.progressBar.observe(viewLifecycleOwner, Observer { isLoading ->
            binding.progressBar.visibility =
                if (isLoading) View.VISIBLE else View.GONE
        })

        // Cargar anuncios al inicio
        viewModel.getAnuncios()

        //Observar la validez del token
        viewModel.navigateToLogin.observe(viewLifecycleOwner) { shouldNavigate ->
            if (shouldNavigate) {
                startActivity(Intent(requireActivity() as MainActivity, Login::class.java))
            }
        }

        return binding.root
    }

    private fun onAnuncioClick(id: Int) {
        val bundle = Bundle().apply {
            putInt("id", id)
            putString("tipoItem", "anuncio")
        }
        val navController = (requireActivity() as MainActivity).navController
        navController.navigate(R.id.infoItemsFragment, bundle)
    }
}
