package com.example.f1hub.ui.view.fragment.content.info

import android.content.SharedPreferences
import android.os.Bundle
import android.util.Log
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.lifecycle.lifecycleScope
import com.bumptech.glide.Glide
import com.bumptech.glide.load.resource.bitmap.CircleCrop
import com.bumptech.glide.load.resource.bitmap.RoundedCorners
import com.example.f1hub.R
import com.example.f1hub.data.dto.`in`.items.ResponseItem
import com.example.f1hub.databinding.FragmentInfoItemsBinding
import com.example.f1hub.di.AppModule
import com.example.f1hub.domain.usecase.ads.GetAllAdsUseCase
import com.example.f1hub.domain.usecase.items.GetAllItemsByUser
import com.example.f1hub.domain.usecase.items.GetAllItemsUseCase
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.coroutines.launch
import javax.inject.Inject

@AndroidEntryPoint
class InfoItemsFragment : Fragment() {

    private lateinit var binding: FragmentInfoItemsBinding

    @Inject lateinit var getAllItemsUseCase: GetAllItemsByUser
    @Inject lateinit var getAllAdsUseCase: GetAllAdsUseCase
    @Inject lateinit var sharedPreferences: SharedPreferences

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentInfoItemsBinding.inflate(inflater, container, false)

        val id = arguments?.getInt("id") ?: -1
        val tipoItem = arguments?.getString("tipoItem", "")

        // Verificar si 'posicion' es válida
        if (id < 0) {
            Log.e("InfoItemsFragment", "⚠️ Id inválido: $id")
            return binding.root
        }

        lifecycleScope.launch {
            binding.progressBar.visibility = View.VISIBLE

            when (tipoItem) {
                "item" -> {
                    val listItems: List<ResponseItem> = getAllItemsUseCase(AppModule.provideToken(sharedPreferences),AppModule.provideUserId(sharedPreferences))
                    if (listItems.isEmpty()) {
                        Log.e("InfoItemsFragment", "⚠️ La lista de items está vacía o el índice es inválido")
                        return@launch
                    }

                    val item = listItems.find { it.id.toInt() == id }!!
                    binding.title.text = item.title
                    binding.flagText.text = item.description


                    // 🖼️ Cargar imagen en formato circular con Glide
                    Glide.with(this@InfoItemsFragment)
                        .load(item.image)
                        .placeholder(R.drawable.loading_bar)
                        .error(R.drawable.not_found)
                        .override(300, 300)
                        .transform(CircleCrop())
                        .into(binding.imagen)

                }

                "anuncio" -> {
                    val listAnuncios = getAllAdsUseCase(AppModule.provideToken(sharedPreferences))
                    if (listAnuncios.isEmpty()) {
                        Log.e("InfoItemsFragment", "⚠️ La lista de anuncios está vacía.")
                        return@launch
                    }

                    val ad = listAnuncios.find { it.id.toInt() == id }
                    if (ad == null) {
                        Log.e("InfoItemsFragment", "⚠️ No se encontró un anuncio con ID: $id")
                        return@launch
                    }

                    binding.title.text = ad.title
                    binding.flagText.text = ad.description

                    // 🖼️ Cargar imagen con Glide
                    Glide.with(this@InfoItemsFragment)
                        .load(ad.image)
                        .placeholder(R.drawable.loading_bar)
                        .error(R.drawable.not_found)
                        .override(300, 300)
                        .transform(CircleCrop())
                        .into(binding.imagen)
                }

            }

            binding.progressBar.visibility = View.GONE
        }

        return binding.root
    }
}
