package com.example.f1hub.ui.view.fragment.dialogues

import android.app.AlertDialog
import android.app.Dialog
import android.os.Bundle
import android.widget.Toast
import androidx.fragment.app.DialogFragment
import com.example.f1hub.R

class DialogConfirmacion(private val listener: OnDeleteConfirmedListener) : DialogFragment() {

    interface OnDeleteConfirmedListener {
        fun onDeleteConfirmed(onResult: (Boolean) -> Unit) // 🔹 Ahora maneja la respuesta de la API
    }

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        return requireActivity().let {
            val builder = AlertDialog.Builder(it)
            builder.setMessage("¿Estás seguro de que quieres eliminar este ítem?")
                .setPositiveButton("Eliminar") { _, _ ->
                    // 🔹 Llamar a la API y manejar el resultado
                    listener.onDeleteConfirmed { isDeleted ->
                        handleDeleteResult(isDeleted)
                    }
                }
                .setNegativeButton("Cancelar") { dialog, _ ->
                    dialog.dismiss()
                }
            builder.create()
        } ?: throw IllegalStateException("Activity cannot be null")
    }

    private fun handleDeleteResult(isDeleted: Boolean) {
        dismiss()
        activity?.runOnUiThread {
            if (isDeleted) {
                Toast.makeText(activity, "Ítem eliminado correctamente", Toast.LENGTH_SHORT).show()
            } else {
                Toast.makeText(activity, "No se pudo eliminar el ítem", Toast.LENGTH_SHORT).show()
            }
        }
    }

}
