package com.example.f1hub.ui.view.login

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.core.view.ViewCompat
import androidx.core.view.WindowInsetsCompat
import com.example.f1hub.R
import com.example.f1hub.data.dto.out.users.UserNoIdDto
import com.example.f1hub.databinding.ActivityRegisterBinding
import com.example.f1hub.domain.usecase.users.RegisterUseCase
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import javax.inject.Inject

@AndroidEntryPoint
class Register : AppCompatActivity() {

    @Inject lateinit var registerUseCase: RegisterUseCase

    private lateinit var binding: ActivityRegisterBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRegisterBinding.inflate(layoutInflater)
        setContentView(binding.root)
        enableEdgeToEdge()

        // Ajustar los márgenes del sistema
        ViewCompat.setOnApplyWindowInsetsListener(binding.main) { v, insets ->
            val systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars())
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom)
            insets
        }

        checkAlreadyLogged()
        setupListeners()
    }

    // Verifica si el usuario ya está logueado
    private fun checkAlreadyLogged() {
        val sharedPreferences = getSharedPreferences("user_log", MODE_PRIVATE)
        Log.d("Register", "Usuario logueado: " + sharedPreferences.getBoolean("logged", false))
        if (sharedPreferences.getBoolean("logged", false))
            navigateToLogin()
    }

    private fun setupListeners() {
        binding.loginButtonRegister.setOnClickListener { navigateToLogin() }

        binding.registerButtonRegister.setOnClickListener {
            val email = binding.emailRegister.text.toString().trim()
            val password = binding.passwordRegister.text.toString().trim()
            val confirmPassword = binding.confirmPasswordRegister.text.toString().trim()
            val username = binding.usernameRegister.text.toString().trim()

            if (email.isEmpty() || password.isEmpty() || confirmPassword.isEmpty() || username.isEmpty()) {
                showToast("Todos los campos son obligatorios")
                return@setOnClickListener
            }

            if (password != confirmPassword) {
                showToast("Las contraseñas no coinciden")
                return@setOnClickListener
            }

            registerUser(email, password, username)
        }
    }

    private fun registerUser(email: String, password: String, username: String) {
        val newUser = UserNoIdDto("user", username, email, password, "")
        CoroutineScope(Dispatchers.Main).launch {
            val response = registerUseCase(newUser)
            if (response != null) {
                showToast("Usuario registrado. Verifica tu correo antes de iniciar sesión.")
                navigateToLogin()
            } else {
                showToast("Error al registrar usuario.")
            }
        }
    }

    private fun navigateToLogin() {
        startActivity(Intent(this, Login::class.java))
        finish()
    }

    private fun showToast(message: String) {
        Toast.makeText(this, message, Toast.LENGTH_LONG).show()
    }
}
