package com.example.f1hub.ui.viewmodel

import android.content.SharedPreferences
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.f1hub.data.dto.`in`.ads.ResponseAd
import com.example.f1hub.di.AppModule
import com.example.f1hub.domain.usecase.ads.GetAllAdsUseCase
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class AnuncioViewModel @Inject constructor(
    private val getAllAdsUseCase: GetAllAdsUseCase,
    private val sharedPreferences: SharedPreferences
) : ViewModel() {

    private val _anuncioLiveData = MutableLiveData<List<ResponseAd>>()
    val anuncioLiveData: LiveData<List<ResponseAd>> get() = _anuncioLiveData

    private val _progressBar = MutableLiveData<Boolean>()
    val progressBar: LiveData<Boolean> get() = _progressBar

    private val _navigateToLogin = MutableLiveData<Boolean>()
    val navigateToLogin: LiveData<Boolean> = _navigateToLogin

    // Carga la lista de anuncios desde el repositorio a través del caso de uso
    fun getAnuncios() {
        viewModelScope.launch {
            _progressBar.value = true
            try {
                val data = getAllAdsUseCase(AppModule.provideToken(sharedPreferences))
                _anuncioLiveData.value = data
            }catch (e: Exception) {
                if (e.message?.contains("401") == true) { // Si hay 401, borrar token y redirige al login
                    handleUnauthorized()
                }
            }
            _progressBar.value = false
        }

    }
    private fun handleUnauthorized() {
        sharedPreferences.edit()
            .remove("auth_token")
            .remove("user_id")
            .apply()
        _navigateToLogin.value = true
    }
}
